Stable version 1.0.2

## This script can help you to start own Internet business anywhere in the world. The system allows you to run a super-modern, interactive and fast website.

[![Best script Real estate agencies & Travel agencies.](https://github.com/reactpython/best_script_for_agencies/blob/master/intro_booking.gif?raw=true)](https://tenerifebook.com)

# The script supports:

-   **Selling Entertainment, Tours & Everything!**
-   **AirBNB script for Property Rental**    
-   **Classified for Real Estate agency**

# Demo:

-   **Website:** https://mirador.online
-   **Admin:** https://mirador.online/admin/    
-   **Login:** demo
-   **Password:** demodemo


### Real example [Entertainment in Tenerife — online](https://tenerifebook.com)

# Modules

**Mobile version**
Our script based on ReactJS technology and works great on all smartphones and tablets — check!

**SEO**
The site is perfectly adapted for search engines and supports the Open-Graph & JsonLD protocols.
The news section allows you to post SEO-text with automatic relinking.

**Discount system**
Allows you to set global discounts or hold one-time promotions. The discount is calculated from the amount of your    commission which    specified into the price of each offer.

**TripAdvisor Reviews**
Automatic parsing reviews with auto-rewriting text.
Gradual addition of reviews to your website with cross-linking, for the natural increasing of content.

**Flexible price management**
The final price of your offers on the site is formed from the basic price of the supplier and your commission.

**Support Chat**
Dynamic form placed in all pages of the site, allowing customers to send requests to your email.

**Customers and orders**
All orders arriving in the system have extended data of prices with a convenient system of customer management.

**Personal Area**
You can allow your users to add their objects to your website through their personal account.

# Other features:

-   **Booking in two clicks** — the interface allows you to make an order easily and simply!
-   **White-Label** — we do not place our logos.
-   **Unlimited** number of copies of your script.
-   **Auto-scaling photos** — don’t think about the size of photos, our script optimizes them independently.
-   **Youtube-video** — specify the link to the video and the video will appear at the offer page.
-   **Caching algorithm** — loading pages occurs faster than 1 second.
-   **SSL-security** certificate based on CloudFlare. Your site will work through a secure https protocol.
-   **Email notifications.** Receive email notifications for orders.    
-   **Auto-update system.**

## In the near future:

-   Integration with several languages.
-   Payments by cards    
-   Autoposting to Facebook, Instagram
    

## Installation

**Script made with:** ReactJS, Django v2, Ubuntu.
Installation takes place automatically in 5 minutes, via the Docker system. First installation for free!

> *Detailed installation instructions you will receive by email.*
> *If necessary, we can adapt templates for your business — the cost depends on the amount of work.*


## Contact us

-   [Contact Us](mailto:imconfirmer@gmail.com)
-   [At Facebook](https://www.facebook.com/profile.php?id=100000600443708)